package com.cpp.web.controller.regulation;

import cn.hutool.core.date.DateUtil;
import com.cpp.common.core.domain.R;
import com.cpp.web.domain.station.ForecastPowerShortTermStation;
import com.cpp.web.domain.station.WeatherStationStatusData;
import com.cpp.web.service.station.ForecastPowerShortTermStationService;
import com.cpp.web.utils.DateTimeUtil;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;


/**
 * 短期调控
 *
 * @author whc
 * @date 2022-03-18 15:49:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/dqRegulationController")
public class DqRegulationController {
    @Autowired
    ForecastPowerShortTermStationService forecastPowerShortTermStationService;


    @GetMapping("/queryData")
    public R queryData(String stationCode, Long time) {
        int howLongAgo = DateTimeUtil.getDaysBetweenTwoDate(System.currentTimeMillis(),time);
        // 获取要调整的短期那天的最后时间
        long eneTime = DateTimeUtil.getDayLastTime(time).getTime();

        // 获取短期上报数据(原始数据)
        Map<String, Object> map = new HashMap<>();
        List<ForecastPowerShortTermStation> forecastPowerShortTermStationList = forecastPowerShortTermStationService.findByForecastTimeBetweenAndForecastHowLongAgoAndStationCode(time, eneTime, howLongAgo, stationCode);
        if (forecastPowerShortTermStationList.size()>0){
            forecastPowerShortTermStationList.sort(Comparator.comparing(ForecastPowerShortTermStation::getTime));
            List list  = new ArrayList();
            for (ForecastPowerShortTermStation forecastPowerShortTermStation:forecastPowerShortTermStationList){
                list.add(forecastPowerShortTermStation.getFpValue());
            }
            map.put("ysData",list);
            return R.ok(map);
        }
        else{
            String timeStr = DateUtil.format(new Date(time),"yyyy-MM-dd");
            return R.fail("调控日期："+timeStr+"，今日无上报数据！");
        }
    }

}
